==> jc-1.4.0.tar.gz: soot/dava/internal/AST/ASTTryNode__24container.h <==
// public class soot.dava.internal.AST.ASTTryNode$container

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5dce9c70ed4bcadf soot_dava_internal_AST_ASTTryNode__24container

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_internal_AST_ASTTryNode__24container_H_
#define _JC_soot_dava_internal_AST_ASTTryNode__24container_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_dava_internal_AST_ASTTryNode$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_refs	_jc_soot_dava_internal_AST_ASTTryNode__24container$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_nonrefs	_jc_soot_dava_internal_AST_ASTTryNode__24container$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$refs	_jc_soot_dava_internal_AST_ASTTryNode__24container$refs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$nonrefs	_jc_soot_dava_internal_AST_ASTTryNode__24container$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object	_jc_soot_dava_internal_AST_ASTTryNode__24container$object;

typedef const struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vmethods	_jc_soot_dava_internal_AST_ASTTryNode__24container$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vtable	_jc_soot_dava_internal_AST_ASTTryNode__24container$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vtype	_jc_soot_dava_internal_AST_ASTTryNode__24container$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTTryNode__24container$method$_init$65072621568c5f87(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vmethods {
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_AST_ASTTryNode__24container$vmethods	soot_dava_internal_AST_ASTTryNode__24container;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTTryNode__24container$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_refs {
	struct _jc_java_lang_Object$object	*o;
	struct _jc_soot_dava_internal_AST_ASTTryNode$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$refs {
    _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_refs	soot_dava_internal_AST_ASTTryNode__24container;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_nonrefs	soot_dava_internal_AST_ASTTryNode__24container;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object {
	_jc_soot_dava_internal_AST_ASTTryNode__24container$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTTryNode__24container$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTTryNode__24container$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTTryNode__24container$vtype _jc_soot_dava_internal_AST_ASTTryNode__24container$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTTryNode__24container, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTTryNode__24container$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTTryNode__24container_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/AST/ASTTryNode__24container.h <==
// public class soot.dava.internal.AST.ASTTryNode$container

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5dce9c70ed4bcadf soot_dava_internal_AST_ASTTryNode__24container

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_internal_AST_ASTTryNode__24container_H_
#define _JC_soot_dava_internal_AST_ASTTryNode__24container_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_dava_internal_AST_ASTTryNode$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_refs	_jc_soot_dava_internal_AST_ASTTryNode__24container$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_nonrefs	_jc_soot_dava_internal_AST_ASTTryNode__24container$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$refs	_jc_soot_dava_internal_AST_ASTTryNode__24container$refs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$nonrefs	_jc_soot_dava_internal_AST_ASTTryNode__24container$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object	_jc_soot_dava_internal_AST_ASTTryNode__24container$object;

typedef const struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vmethods	_jc_soot_dava_internal_AST_ASTTryNode__24container$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vtable	_jc_soot_dava_internal_AST_ASTTryNode__24container$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vtype	_jc_soot_dava_internal_AST_ASTTryNode__24container$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTTryNode__24container$method$_init$65072621568c5f87(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vmethods {
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_AST_ASTTryNode__24container$vmethods	soot_dava_internal_AST_ASTTryNode__24container;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTTryNode__24container$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_refs {
	struct _jc_java_lang_Object$object	*o;
	struct _jc_soot_dava_internal_AST_ASTTryNode$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$refs {
    _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_refs	soot_dava_internal_AST_ASTTryNode__24container;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_AST_ASTTryNode__24container$sub_nonrefs	soot_dava_internal_AST_ASTTryNode__24container;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object {
	_jc_soot_dava_internal_AST_ASTTryNode__24container$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTTryNode__24container$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTTryNode__24container$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTTryNode__24container$vtype _jc_soot_dava_internal_AST_ASTTryNode__24container$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTTryNode__24container, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTTryNode__24container$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTTryNode__24container_H_ */
